@@ -28,12 +28,15 @@
 #include <stdio.h>
 #include <string.h>
 
+#ifndef TRUE
 #define TRUE 1
-#define FALSE -1 
-/* #define NULL 0 */
+#endif
+#ifndef FALSE
+#define FALSE 0
+#endif
 
 /*---- --- for use with these definitions of TRUE and FALSE -------------- */
-#define NOT(x) (((x) == FALSE) ? 1 : -1)
+#define NOT(x) (((x) == FALSE) ? TRUE : FALSE)
 
 #ifdef TCL_WRAPPER
   #define malloc Tcl_Alloc
